pub fn sys_yield(trapframe: &mut Trapframe) -> usizeExpand description
Yield execution to the scheduler
This is a cooperative scheduling primitive similar to sched_yield(2).
The calling task remains runnable, but allows another ready task to run.
Returns
0on success